@@ -1,6 +1,6 @@
 package Validator::Custom;
 
-our $VERSION = '0.1304';
+our $VERSION = '0.1401';
 
 use 5.008001;
 use strict;
@@ -12,74 +12,67 @@ use Carp 'croak';
 use Validator::Custom::Basic::Constraints;
 use Validator::Custom::Result;
 
+
 __PACKAGE__->dual_attr('constraints', default => sub { {} },
                                       inherit => 'hash_copy');
-
-__PACKAGE__->register_constraint(
-    not_defined       => \&Validator::Custom::Basic::Constraints::not_defined,
-    defined           => \&Validator::Custom::Basic::Constraints::defined,
-    not_space         => \&Validator::Custom::Basic::Constraints::not_space,
-    not_blank         => \&Validator::Custom::Basic::Constraints::not_blank,
-    blank             => \&Validator::Custom::Basic::Constraints::blank,
-    int               => \&Validator::Custom::Basic::Constraints::int,
-    uint              => \&Validator::Custom::Basic::Constraints::uint,
-    ascii             => \&Validator::Custom::Basic::Constraints::ascii,
-    shift             => \&Validator::Custom::Basic::Constraints::shift_array,
-    duplication       => \&Validator::Custom::Basic::Constraints::duplication,
-    length            => \&Validator::Custom::Basic::Constraints::length,
-    regex             => \&Validator::Custom::Basic::Constraints::regex,
-    http_url          => \&Validator::Custom::Basic::Constraints::http_url,
-    selected_at_least => \&Validator::Custom::Basic::Constraints::selected_at_least,
-    greater_than      => \&Validator::Custom::Basic::Constraints::greater_than,
-    less_than         => \&Validator::Custom::Basic::Constraints::less_than,
-    equal_to          => \&Validator::Custom::Basic::Constraints::equal_to,
-    between           => \&Validator::Custom::Basic::Constraints::between,
-    decimal           => \&Validator::Custom::Basic::Constraints::decimal,
-    in_array          => \&Validator::Custom::Basic::Constraints::in_array,
-    trim              => \&Validator::Custom::Basic::Constraints::trim,
-    trim_lead         => \&Validator::Custom::Basic::Constraints::trim_lead,
-    trim_trail        => \&Validator::Custom::Basic::Constraints::trim_trail,
-    trim_collapse     => \&Validator::Custom::Basic::Constraints::trim_collapse
-);
-
+__PACKAGE__->attr('data_filter');
+__PACKAGE__->attr(error_stock => 1);
 __PACKAGE__->attr('rule');
 __PACKAGE__->attr(shared_rule => sub { [] });
-__PACKAGE__->attr(error_stock => 1);
-__PACKAGE__->attr('data_filter');
-__PACKAGE__->attr(default_messages => sub { {} });
 
 __PACKAGE__->attr(syntax => <<'EOS');
 ### Syntax of validation rule
-    my $rule = [                          # 1. Rule is array ref
-        key1 => [                         # 2. Constraints is array ref
-            'constraint1_1',              # 3. Constraint is string
-            ['constraint1_2', 'error1_2'],#      or arrya ref (message)
-            {'constraint1_3' => 'string'} #      or hash ref (arguments)
-              
-        ],
-        key2 => [
-            {'constraint2_1'              # 4. Argument is string
-              => 'string'},               #
-            {'constraint2_2'              #     or array ref
-              => ['arg1', 'arg2']},       #
-            {'constraint1_3'              #     or hash ref
-              => {k1 => 'v1', k2 => 'v2'}}#
-        ],
-        key3 => [                           
-            [{constraint3_1 => 'string'}, # 5. Combination argument
-             'error3_1' ]                 #     and message
-        ],
-        { key4 => ['key4_1', 'key4_2'] }  # 6. Multi-paramters validation
-            => [
-                'constraint4_1'
-               ],
-        key5 => [
-            '@constraint5_1'              # 7. Multi-values validation
-        ]
-    ];
+my $rule = [                              # 1. Rule is array ref
+    key => [                              # 2. Constraints is array ref
+        'constraint',                     # 3. Constraint is string
+        {'constraint' => 'args'}          #      or hash ref (arguments)
+        ['constraint', 'err'],            #      or arrya ref (message)
+    ],
+    key => [                           
+        [{constraint => 'args'}, 'err']   # 4. With argument and message
+    ],
+    {key => ['key1', 'key2']} => [        # 5. Multi-paramters validation
+        'constraint'
+    ],
+    key => [
+        '@constraint'                     # 6. Multi-values validation
+    ],
+    key => \%OPTIONS => [                 # 7. With options
+        'constraint'
+    ]
+];
 
 EOS
 
+
+__PACKAGE__->register_constraint(
+    ascii             => \&Validator::Custom::Basic::Constraints::ascii,
+    between           => \&Validator::Custom::Basic::Constraints::between,
+    blank             => \&Validator::Custom::Basic::Constraints::blank,
+    decimal           => \&Validator::Custom::Basic::Constraints::decimal,
+    defined           => sub { defined $_[0] },
+    duplication       => \&Validator::Custom::Basic::Constraints::duplication,
+    equal_to          => \&Validator::Custom::Basic::Constraints::equal_to,
+    greater_than      => \&Validator::Custom::Basic::Constraints::greater_than,
+    http_url          => \&Validator::Custom::Basic::Constraints::http_url,
+    int               => \&Validator::Custom::Basic::Constraints::int,
+    in_array          => \&Validator::Custom::Basic::Constraints::in_array,
+    length            => \&Validator::Custom::Basic::Constraints::length,
+    less_than         => \&Validator::Custom::Basic::Constraints::less_than,
+    not_defined       => \&Validator::Custom::Basic::Constraints::not_defined,
+    not_space         => \&Validator::Custom::Basic::Constraints::not_space,
+    not_blank         => \&Validator::Custom::Basic::Constraints::not_blank,
+    uint              => \&Validator::Custom::Basic::Constraints::uint,
+    regex             => \&Validator::Custom::Basic::Constraints::regex,
+    selected_at_least => \&Validator::Custom::Basic::Constraints::selected_at_least,
+    shift             => \&Validator::Custom::Basic::Constraints::shift_array,
+    trim              => \&Validator::Custom::Basic::Constraints::trim,
+    trim_collapse     => \&Validator::Custom::Basic::Constraints::trim_collapse,
+    trim_lead         => \&Validator::Custom::Basic::Constraints::trim_lead,
+    trim_trail        => \&Validator::Custom::Basic::Constraints::trim_trail
+);
+
+
 sub register_constraint {
     my $invocant = shift;
     
@@ -90,6 +83,8 @@ sub register_constraint {
     return $invocant;
 }
 
+our %VALID_OPTIONS = map {$_ => 1} qw/message default copy/;
+
 sub validate {
     my ($self, $data, $rule) = @_;
     
@@ -119,7 +114,6 @@ sub validate {
     # Result
     my $result = Validator::Custom::Result->new;
     $result->{_error_infos} = {};
-    $result->{_default_messages} = $self->default_messages;
     
     # Save raw data
     $result->raw_data($data);
@@ -143,8 +137,18 @@ sub validate {
         # Increment position
         $position++;
         
-        # Key and constraints
-        my ($key, $constraints) = @{$rule}[$i, ($i + 1)];
+        # Key, options, and constraints
+        my $key = $rule->[$i];
+        my $options = $rule->[$i + 1];
+        my $constraints;
+        if (ref $options eq 'HASH') {
+            $constraints = $rule->[$i + 2];
+            $i++;
+        }
+        else {
+            $constraints = $options;
+            $options = {};
+        }
         
         # Check constraints
         croak "Constraints of validation rule must be array ref\n" .
@@ -161,6 +165,16 @@ sub validate {
         }
         my $keys = ref $key eq 'ARRAY' ? $key : [$key];
         
+        # Check option
+        foreach my $oname (keys %$options) {
+            croak qq{Option "$oname" of "$result_key" is invalid name}
+              unless $VALID_OPTIONS{$oname};
+        }
+        
+        # Is data copy?
+        my $copy = 1;
+        $copy = $options->{copy} if exists $options->{copy};
+        
         # Check missing parameters
         my $found_missing_param;
         my $missing_params = $result->missing_params;
@@ -172,7 +186,11 @@ sub validate {
                 $found_missing_param = 1;
             }
         }
-        next if $found_missing_param;
+        if ($found_missing_param) {
+            $result->data->{$result_key} = $options->{default}
+              if exists $options->{default} && $copy;
+            next;
+        }
         
         # Already valid
         next if $valid_keys->{$result_key};
@@ -308,6 +326,7 @@ sub validate {
             unless ($is_valid) {
                 
                 # Resist error info
+                $message = $options->{message} unless defined $message;
                 $result->{_error_infos}->{$result_key} = {
                     message      => $message,
                     position     => $position,
@@ -316,12 +335,17 @@ sub validate {
                 }
                   unless exists $result->{_error_infos}->{$result_key};
                 
+                # Set default value
+                $result->data->{$result_key} = $options->{default}
+                  if exists $options->{default} && $copy;
+                
                 # No Error strock
                 unless ($error_stock) {
                     # Check rest constraint
                     my $found;
                     for (my $k = $i + 2; $k < @{$rule}; $k += 2) {
                         my $key = $rule->[$k];
+                        $k++ if ref $rule->[$k + 1] eq 'HASH';
                         $key = (keys %$key)[0] if ref $key eq 'HASH';
                         $found = 1 if $key eq $result_key;
                     }
@@ -332,7 +356,7 @@ sub validate {
         }
         
         # Result data
-        $result->data->{$result_key} = $value;
+        $result->data->{$result_key} = $value if $copy;
         
         # Key is valid
         $valid_keys->{$result_key} = 1;
@@ -381,51 +405,56 @@ Basic usages
         name => [
             ['not_blank',        "Name must be exists"],
             [{length => [1, 5]}, "Name length must be 1 to 5"]
+        ],
+        price => {default => 1000, message => 'price must be integer'} => [
+            'int'
         ]
     ];
     
     # Validate
-    my $vresult = $vc->validate($data, $rule);
+    my $result = $vc->validate($data, $rule);
 
 Result of validation
 
     ### Validator::Custom::Result
-    
-    # Chacke if the data is valid.
-    my $is_valid = $vresult->is_valid;
-    
-    # (experimental) Missing paramters
-    my $missing_params = $vresult->missing_params;
-    
-    # Error messages
-    my $messages = $vresult->messages;
 
-    # Error messages to hash ref
-    my $messages_hash = $vresult->messages_to_hash;
+    my $result = $vc->validate($data, $rule);
     
-    # Error message
-    my $message = $vresult->message('age');
+    # (experimental) Chacke if the result is valid.
+    my $is_ok = $result->is_ok;
+    
+    # (experimental) Check the existence of missing parameter
+    my $has_missing_param = $result->has_missing
+    
+    # (experimental) Missing parameters
+    my $missing_params = $result->missing_params;
+    
+    # (experimental) Chack if the data has invalid parameter
+    my $has_invalid = $resutl->has_invalid;
     
     # Invalid parameter names
-    my $invalid_params = $vresult->invalid_params;
+    my $invalid_params = $result->invalid_params;
     
     # Invalid rule keys
-    my $invalid_rule_keys = $vresult->invalid_rule_keys;
+    my $invalid_rule_keys = $result->invalid_rule_keys;
+
+    # Error messages
+    my $messages = $result->messages;
+
+    # Error messages to hash ref
+    my $messages_hash = $result->message_to_hash;
+    
+    # A error message
+    my $message = $result->message('title');
     
     # Raw data
-    my $raw_data = $vresult->raw_data;
+    my $raw_data = $result->raw_data;
     
     # Result data
-    my $result_data = $vresult->data;
+    my $result_data = $result->data;
     
 Advanced features
 
-    # (experimental) default messages
-    $vc->default_messages({
-        age  => 'age is invalid',
-        name => 'name is invalid'
-    });
-    
     # Register constraint
     $vc->register_constraint(
         email => sub {
@@ -449,7 +478,7 @@ Advanced features
             ['same', 'Two password must be equal']
         ]
     ];
-    $vresult = $vc->validate($data, $rule);
+    $result = $vc->validate($data, $rule);
 
     # "OR" validation
     $rule = [
@@ -597,71 +626,82 @@ and constraint expressions. the format detail is explained in
 
 Validate the data. validate() return L<Validator::Custom::Result> object.
 
-    my $vresult = $vc->validate($data, $rule);
+    my $result = $vc->validate($data, $rule);
 
 =head2 3. Result of validation
 
 L<Validator::Custom::Result> object has the result of validation.
 
-Check if the data is valid.
+Check if the data is ok.
     
-    my $is_valid = $vresult->is_valid;
+    my $is_ok = $result->is_ok;
 
 Error messages
     
     # Error messages
-    my $messages = $vresult->messages;
+    my $messages = $result->messages;
 
     # Error messages to hash ref
-    my $messages_hash = $vresult->messages_to_hash;
+    my $messages_hash = $result->messages_to_hash;
     
     # A error message
-    my $message = $vresult->message('age');
+    my $message = $result->message('age');
 
-Invalid paramter names and invalid result keys
+Check if data has missing paremeters
 
+    # Check if the data has missing parameter
+    my $has_missing = $result->has_missing;
+    
+    # Missing parameters
+    my $missing_params = $result->missing_params;
+
+Invalid parameter names and invalid result keys
+
+    # Check if the data has invalid paramters
+    my $has_invalid = $result->has_invalid;
+    
     # Invalid parameter names
-    my $invalid_params = $vresult->invalid_params;
+    my $invalid_params = $result->invalid_params;
     
     # Invalid rule keys
-    my $invalid_rule_keys = $vresult->invalid_rule_keys;
+    my $invalid_rule_keys = $result->invalid_rule_keys;
 
 Raw data and result data
 
     # Raw data
-    my $raw_data = $vresult->raw_data;
+    my $raw_data = $result->raw_data;
     
     # Result data
-    my $result_data = $vresult->data;
+    my $result_data = $result->data;
 
 B<Examples:>
 
 Check the result and get error messages.
 
-    unless ($vresult->is_valid) {
-        my $messages = $vresult->messages;
+    unless ($result->is_ok) {
+        my $messages = $result->messages;
         
         # Do something
     }
 
 Check the result and get error messages as hash reference
 
-    unless ($vresult->is_valid) {
-        my $messages = $vresult->messages_to_hash;
+    unless ($result->is_ok) {
+        my $messages = $result->messages_to_hash;
 
         # Do something
     }
 
 Combination with L<HTML::FillInForm>
 
-    unless ($vresult->is_valid) {
+    unless ($result->is_ok) {
         
         my $html = get_something_way();
         
         # Fill in form
         $html = HTML::FillInForm->fill(
-            \$html, $vresult->raw_data,
-            ignore_fields => $vresult->invalid_params
+            \$html, $result->raw_data,
+            ignore_fields => $result->invalid_params
         );
         
         # Do something
@@ -689,7 +729,11 @@ expression.
             'not_blank',
             'int'
         ]
-        # PARAMETER_NAME => [
+        price => {default => 1000, message => 'price must be integer'} => [
+            'int'
+        ]
+
+        # PARAMETER_NAME => OPTIONS(this is optional) => [
         #    CONSTRIANT_EXPRESSION1
         #    CONSTRAINT_EXPRESSION2
         # ]
@@ -745,6 +789,32 @@ B<Example:>
         ]
     ];
 
+=head3 C<Options>
+
+Options can be set.
+
+=over 4
+
+=item 1. message
+
+Message when the result has invalid parameter
+
+     {message => "This key is invalid"}
+
+=item 2. default
+
+default value. This value is set if the result has missing paramter or has invalid paramter.
+
+    {default => 5}
+
+=item 3. copy
+
+the value is copied to result's data or not. default to 1.
+
+    {copy => 0}
+
+=back
+
 =head3 C<Multi-paramters validation>
 
 Multi-paramters validation is available.
@@ -966,16 +1036,6 @@ finished soon after invalid value is found.
 
 Constraint functions.
 
-=head2 C<error_stock>
-
-    my $error_stock = $vc->error_stcok;
-    $vc             = $vc->error_stock(1);
-
-If error_stock is set to 1, all validation error is stocked.
-If error_stock is set 0, Validation is finished soon after a error occur.
-
-Default to 1. 
-
 =head2 C<data_filter>
 
     my $filter = $vc->data_filter;
@@ -991,7 +1051,17 @@ Filter input data. If data is not hash reference, you can convert the data to ha
             
             return $data;
         }
-    )
+    );
+
+=head2 C<error_stock>
+
+    my $error_stock = $vc->error_stcok;
+    $vc             = $vc->error_stock(1);
+
+If error_stock is set to 1, all validation error is stocked.
+If error_stock is set 0, Validation is finished soon after a error occur.
+
+Default to 1. 
 
 =head2 C<rule>
 
@@ -1002,31 +1072,23 @@ Rule for validation.
 Validation rule has the following syntax.
 
     # Rule syntax
-    my $rule = [                          # 1. Validation rule is array ref
-        key1 => [                         # 2. Constraints is array ref
-            'constraint1_1',              # 3. Constraint is string
-            ['constraint1_2', 'error1_2'],#      or arrya ref (message)
-            {'constraint1_3' => 'string'} #      or hash ref (arguments)
-              
+    my $rule = [                              # 1. Rule is array ref
+        key => [                              # 2. Constraints is array ref
+            'constraint',                     # 3. Constraint is string
+            {'constraint' => 'args'}          #      or hash ref (arguments)
+            ['constraint', 'err'],            #      or arrya ref (message)
         ],
-        key2 => [
-            {'constraint2_1'              # 4. Argument is string
-              => 'string'},               #
-            {'constraint2_2'              #     or array ref
-              => ['arg1', 'arg2']},       #
-            {'constraint1_3'              #     or hash ref
-              => {k1 => 'v1', k2 => 'v2'}}#
+        key => [                           
+            [{constraint => 'args'}, 'err']   # 4. With argument and message
         ],
-        key3 => [                           
-            [{constraint3_1 => 'string'}, # 5. Combination argument
-             'error3_1' ]                 #     and message
+        {key => ['key1', 'key2']} => [        # 5. Multi-paramters validation
+            'constraint'
         ],
-        { key4 => ['key4_1', 'key4_2'] }  # 6. Multi-parameters validation
-            => [
-                'constraint4_1'
-               ],
-        key5 => [
-            '@constraint5_1'              # 7. Multi-values validation
+        key => [
+            '@constraint'                     # 6. Multi-values validation
+        ],
+        key => \%OPTIONS => [                 # 7. With options
+            'constraint'
         ]
     ];
 
@@ -1049,16 +1111,20 @@ Shared rule. Shared rule is added the head of normal rule.
 
 Syntax of rule.
 
-=head2 (experimental) default_messages
-
-    my $default_messages = $vc->default_messages;
-    $vc                  = $vc->default_messages(\%default_messages);
-
 =head1 METHODS
 
 L<Validator::Custom> inherits all methods from L<Object::Simple>
 and implements the following new ones.
 
+=head2 C<validate>
+
+    $result = $vc->validate($data, $rule);
+    $result = $vc->validate($data);
+
+Validate the data.
+Return value is L<Validator::Custom::Result> object.
+If the rule of second arument is ommited, rule attribute is used for validation.
+
 =head2 C<register_constraint>
 
     $vc->register_constraint(%constraint);
@@ -1080,52 +1146,26 @@ the value is valid.
         }
     );
 
-=head2 C<validate>
-
-    $vresult = $vc->validate($data, $rule);
-    $vresult = $vc->validate($data);
-
-Validate the data.
-Return value is L<Validator::Custom::Result> object.
-If the rule of second arument is ommited, rule attribute is used for validation.
-
 =head1 Constraints
 
-=head2 C<defined>
+=head2 C<ascii>
 
-Check if the data is defined.
+check is the data consists of only ascii code.
 
-=head2 C<not_defined>
+=head2 C<between>
 
-Check if the data is not defined.
+Numeric comparison
 
-=head2 C<not_blank>
-
-Check if the data is not blank.
+    my $rule = [
+        age => [
+            {between => [1, 20]}
+        ]
+    ];
 
 =head2 C<blank>
 
 Check if the is blank.
 
-=head2 C<not_space>
-
-Check if the data do not containe space.
-
-=head2 C<int>
-
-Check if the data is integer.
-    
-    # valid data
-    123
-    -134
-
-=head2 C<uint>
-
-Check if the data is unsigned integer.
-
-    # valid data
-    123
-    
 =head2 C<decimal>
     
     my $data = { num => '123.45678' };
@@ -1139,9 +1179,69 @@ Check if the data is unsigned integer.
 
 Each numbers (3,5) mean maximum digits before/after '.'
 
-=head2 C<ascii>
+=head2 C<defined>
 
-check is the data consists of only ascii code.
+Check if the data is defined.
+
+=head2 C<duplication>
+
+Check if the two data are same or not.
+
+    my $data = {mail1 => 'a@somehost.com', mail2 => 'a@somehost.com'};
+    my $rule => [
+        [qw/mail1 mail2/] => [
+            'duplication'
+        ]
+    ];
+
+=head2 C<equal_to>
+
+Numeric comparison
+
+    my $rule = [
+        age => [
+            {equal_to => 25}
+        ]
+    ];
+    
+=head2 C<greater_than>
+
+Numeric comparison
+
+    my $rule = [
+        age => [
+            {greater_than => 25}
+        ]
+    ];
+
+=head2 C<http_url>
+
+Verify it is a http(s)-url
+
+    my $data = { url => 'http://somehost.com' };
+    my $rule => [
+        url => [
+            'http_url'
+        ]
+    ];
+
+=head2 C<int>
+
+Check if the data is integer.
+    
+    # valid data
+    123
+    -134
+
+=head2 C<in_array>
+
+Check if the food ordered is in menu
+
+    my $rule = [
+        food => [
+            {in_array => [qw/sushi bread apple/]}
+        ]
+    ];
 
 =head2 C<length>
 
@@ -1166,14 +1266,43 @@ the range between 4 and 10.
         ]
     ];
 
-=head2 C<http_url>
+=head2 C<less_than>
 
-Verify it is a http(s)-url
+Numeric comparison
 
-    my $data = { url => 'http://somehost.com' };
+    my $rule = [
+        age => [
+            {less_than => 25}
+        ]
+    ];
+
+=head2 C<not_blank>
+
+Check if the data is not blank.
+
+=head2 C<not_defined>
+
+Check if the data is not defined.
+
+=head2 C<not_space>
+
+Check if the data do not containe space.
+
+=head2 C<uint>
+
+Check if the data is unsigned integer.
+
+    # valid data
+    123
+    
+=head2 C<regex>
+
+Check with regular expression.
+    
+    my $data = {str => 'aaa'};
     my $rule => [
-        url => [
-            'http_url'
+        str => [
+            {regex => qr/a{3}/}
         ]
     ];
 
@@ -1193,28 +1322,6 @@ Verify the quantity of selected parameters is counted over allowed minimum.
         ]
     ];
 
-=head2 C<regex>
-
-Check with regular expression.
-    
-    my $data = {str => 'aaa'};
-    my $rule => [
-        str => [
-            {regex => qr/a{3}/}
-        ]
-    ];
-
-=head2 C<duplication>
-
-Check if the two data are same or not.
-
-    my $data = {mail1 => 'a@somehost.com', mail2 => 'a@somehost.com'};
-    my $rule => [
-        [qw/mail1 mail2/] => [
-            'duplication'
-        ]
-    ];
-
 =head2 C<shift>
 
 Shift the head of array reference.
@@ -1226,56 +1333,6 @@ Shift the head of array reference.
         ]
     ];
 
-=head2 C<greater_than>
-
-Numeric comparison
-
-    my $rule = [
-        age => [
-            {greater_than => 25}
-        ]
-    ];
-
-=head2 C<less_than>
-
-Numeric comparison
-
-    my $rule = [
-        age => [
-            {less_than => 25}
-        ]
-    ];
-
-=head2 C<equal_to>
-
-Numeric comparison
-
-    my $rule = [
-        age => [
-            {equal_to => 25}
-        ]
-    ];
-    
-=head2 C<between>
-
-Numeric comparison
-
-    my $rule = [
-        age => [
-            {between => [1, 20]}
-        ]
-    ];
-
-=head2 C<in_array>
-
-Check if the food ordered is in menu
-
-    my $rule = [
-        food => [
-            {in_array => [qw/sushi bread apple/]}
-        ]
-    ];
-
 =head2 C<trim>
 
 Trim leading and trailing white space
@@ -1286,6 +1343,16 @@ Trim leading and trailing white space
         ],
     ];
     
+=head2 C<trim_collapse>
+
+Trim leading and trailing white space, and collapse all whitespace characters into a single space.
+
+    my $rule = [
+        key1 => [
+            ['trim_collapse']  # "  \n a \r\n b\nc  \t" -> 'a b c'
+        ],
+    ];
+
 =head2 C<trim_lead>
 
 Trim leading white space
@@ -1306,16 +1373,6 @@ Trim trailing white space
         ]
     ];
 
-=head2 C<trim_collapse>
-
-Trim leading and trailing white space, and collapse all whitespace characters into a single space.
-
-    my $rule = [
-        key1 => [
-            ['trim_collapse']  # "  \n a \r\n b\nc  \t" -> 'a b c'
-        ],
-    ];
-
 =head1 BUGS
 
 Please tell me the bugs.
