@@ -7,21 +7,77 @@ use base 'Object::Simple';
 
 use Carp 'croak';
 
+
 __PACKAGE__->attr(data           => sub { {} });
-__PACKAGE__->attr(raw_data       => sub { {} });
 __PACKAGE__->attr(missing_params => sub { [] });
+__PACKAGE__->attr(raw_data       => sub { {} });
+
 
 our $DEFAULT_MESSAGE = 'Error message not specified';
 
-sub is_valid {
-    my $self = shift;
+
+sub error_reason {
+    my ($self, $name) = @_;
     
-    # Is valid?
-    return keys %{$self->{_error_infos}} || @{$self->missing_params}
-         ? 0 : 1;
+    # Parameter name not specifed
+    croak 'Parameter name must be specified'
+      unless $name;
+    
+    # Error reason
+    return $self->{_error_infos}->{$name}{reason};
 }
 
-sub has_missing_param { @{shift->missing_params} ? 1 : 0 }
+sub has_invalid {
+    my $self = shift;
+    
+    # Has invalid parameter?
+    return keys %{$self->{_error_infos}} ? 1 : 0;
+}
+
+sub has_missing { @{shift->missing_params} ? 1 : 0 }
+
+sub invalid_params {
+    my $self = shift;
+    
+    # Invalid parameter names
+    my @invalid_params;
+    foreach my $name (@{$self->invalid_rule_keys}) {
+        my $param = $self->{_error_infos}->{$name}{original_key};
+        $param = [$param] unless ref $param eq 'ARRAY';
+        push @invalid_params, @$param;
+    }
+    
+    return \@invalid_params;
+}
+
+sub invalid_rule_keys {
+    my $self = shift;
+    
+    # Invalid rule keys
+    my $error_infos = $self->{_error_infos};
+    my @invalid_rule_keys = sort { $error_infos->{$a}{position} <=>
+                              $error_infos->{$b}{position} }
+                              keys %$error_infos;
+    
+    return \@invalid_rule_keys;
+}
+
+sub is_ok {
+    my $self = shift;
+    
+    # Is ok?
+    return !$self->has_invalid && !$self->has_missing ? 1 : 0;
+}
+
+sub message {
+    my ($self, $name) = @_;
+    
+    # Parameter name not specifed
+    croak 'Parameter name must be specified'
+      unless $name;
+    
+    return $self->messages_to_hash->{$name};
+}
 
 sub messages {
     my $self = shift;
@@ -59,57 +115,12 @@ sub messages_to_hash {
     return $messages;
 }
 
-sub message {
-    my ($self, $name) = @_;
-    
-    # Parameter name not specifed
-    croak 'Parameter name must be specified'
-      unless $name;
-    
-    return $self->messages_to_hash->{$name};
-}
-
-sub invalid_params {
-    my $self = shift;
-    
-    # Invalid parameter names
-    my @invalid_params;
-    foreach my $name (@{$self->invalid_rule_keys}) {
-        my $param = $self->{_error_infos}->{$name}{original_key};
-        $param = [$param] unless ref $param eq 'ARRAY';
-        push @invalid_params, @$param;
-    }
-    
-    return \@invalid_params;
-}
-
-sub invalid_rule_keys {
-    my $self = shift;
-    
-    # Invalid rule keys
-    my $error_infos = $self->{_error_infos};
-    my @invalid_rule_keys = sort { $error_infos->{$a}{position} <=>
-                              $error_infos->{$b}{position} }
-                              keys %$error_infos;
-    
-    return \@invalid_rule_keys;
-}
-
-sub error_reason {
-    my ($self, $name) = @_;
-    
-    # Parameter name not specifed
-    croak 'Parameter name must be specified'
-      unless $name;
-    
-    # Error reason
-    return $self->{_error_infos}->{$name}{reason};
-}
 
 ### Deprecated attributes and methods
 
 __PACKAGE__->attr(error_infos    => sub { {} });
 
+
 sub add_error_info {
     my $self = shift;
     
@@ -120,6 +131,24 @@ sub add_error_info {
     return $self;
 }
 
+sub error { shift->message(@_) }
+
+sub errors { 
+    return wantarray
+         ? @{shift->messages(@_)}
+         : shift->messages(@_);
+}
+
+sub errors_to_hash { shift->messages_to_hash(@_) }
+
+sub invalid_keys {
+    return wantarray
+         ? @{shift->invalid_rule_keys(@_)}
+         : shift->invalid_rule_keys(@_);
+}
+
+sub is_valid { shift->is_ok(@_) }
+
 sub remove_error_info {
     my ($self, $key) = @_;
     
@@ -129,19 +158,6 @@ sub remove_error_info {
     return $self;
 }
 
-sub error { shift->message(@_) }
-sub errors { 
-    return wantarray
-         ? @{shift->messages(@_)}
-         : shift->messages(@_);
-}
-sub errors_to_hash { shift->messages_to_hash(@_) }
-sub invalid_keys {
-    return wantarray
-         ? @{shift->invalid_rule_keys(@_)}
-         : shift->invalid_rule_keys(@_);
-}
-
 1;
 
 =head1 NAME
@@ -153,15 +169,24 @@ Validator::Custom::Result - Result of validation
     # Result
     my $result = $vc->validate($data, $rule);
     
-    # Chacke if the result is valid.
-    my $is_valid = $result->is_valid;
+    # (experimental) Chacke if the result is valid.
+    my $is_ok = $result->is_ok;
     
-    # (experimental) Check the existence of missing paramter
-    my $has_missing_param = $result->has_missing_param
+    # (experimental) Check the existence of missing parameter
+    my $has_missing_param = $result->has_missing
     
     # (experimental) Missing parameters
     my $missing_params = $result->missing_params;
     
+    # (experimental) Chack if the data has invalid parameter
+    my $has_invalid = $result->has_invalid;
+    
+    # Invalid parameter names
+    my $invalid_params = $result->invalid_params;
+    
+    # Invalid rule keys
+    my $invalid_rule_keys = $result->invalid_rule_keys;
+
     # Error messages
     my $messages = $result->messages;
 
@@ -171,12 +196,6 @@ Validator::Custom::Result - Result of validation
     # A error message
     my $message = $result->message('title');
     
-    # Invalid parameter names
-    my $invalid_params = $result->invalid_params;
-    
-    # Invalid rule keys
-    my $invalid_rule_keys = $result->invalid_rule_keys;
-    
     # Raw data
     my $raw_data = $result->raw_data;
     
@@ -192,6 +211,13 @@ Validator::Custom::Result - Result of validation
 
 Result data.
 
+=head2 C<(experimental) missing_params>
+
+    my $missing_params = $result->missing_params;
+    $result            = $result->missing_params($missing_params);
+
+Missing parameters
+
 =head2 C<raw_data>
 
     my $data  = $result->raw_data;
@@ -199,13 +225,6 @@ Result data.
 
 Raw data soon after data_filter is excuted.
 
-=head2 C<(experimental) missing_params>
-
-    my $missing_params = $result->missing_params;
-    $result            = $result->missing_params($missing_params);
-
-Missing paramters
-
 =head2 C<(depricated) error_infos>
 
     my $error_infos = $result->error_infos;
@@ -218,23 +237,30 @@ Error informations.
 L<Validator::Custom::Result> inherits all methods from L<Object::Simple>
 and implements the following new ones.
 
-=head2 C<is_valid>
+=head2 C<error_reason>
 
-    $is_valid = $result->is_valid;
+    $error_reason = $result->error_reason('title');
 
-Check if the result is valid.
+Error reason. This is constraint name.
 
-=head2 C<(experimental) has_missing_param>
+=head2 C<(experimental) has_invalid>
 
-    my $has_missing_param = $result->has_missing_param;
+    my $has_invalid = $result->has_invalid;
+
+Check if the data has invalid parameter
+
+=head2 C<(experimental) has_missing>
+
+    my $has_missing_param = $result->has_missing;
 
 Check the existence of missing parameter.
 
-=head2 C<messages>
+=head2 C<is_ok>
 
-    $messages = $result->messages;
+    $is_ok = $result->is_ok;
 
-Error messages.
+Check if the result is ok. ok means that
+data has no missing parameter and no invalid parameter.
 
 =head2 C<message>
 
@@ -242,6 +268,12 @@ Error messages.
 
 Error message.
 
+=head2 C<messages>
+
+    $messages = $result->messages;
+
+Error messages.
+
 =head2 C<messages_to_hash>
 
     $messages = $result->messages_to_hash;
@@ -260,24 +292,12 @@ Invalid raw data parameter names.
 
 Invalid rule keys
 
-=head2 C<error_reason>
-
-    $error_reason = $result->error_reason('title');
-
-Error reason. This is constraint name.
-
 =head2 C<(depricated) add_error_info>
 
     $result->add_error_info($name => $error_info);
 
 Add error informations.
 
-=head2 C<(depricated) remove_error_info>
-
-    $result->remove_error_info($name);
-
-Remove error information.
-
 =head2 C<(deprecated) errors>
 
 errors() is deprecated. Please use message() instead.
@@ -287,14 +307,6 @@ errors() is deprecated. Please use message() instead.
 
 Error messages.
 
-=head2 C<(deprecated) errors_to_hash>
-
-errors_to_hash() is deprecated. Please use messages_to_hash() instead.
-
-    $errors = $result->errors_to_hash;
-
-Error messages to hash reference.
-
 =head2 C<(deprecated) error> 
 
 error() is deprecated. Use message() instead.
@@ -303,6 +315,14 @@ error() is deprecated. Use message() instead.
 
 A error message
 
+=head2 C<(deprecated) errors_to_hash>
+
+errors_to_hash() is deprecated. Please use messages_to_hash() instead.
+
+    $errors = $result->errors_to_hash;
+
+Error messages to hash reference.
+
 =head2 C<(deprecated) invalid_keys>
 
 invalid_keys() is deprecated. Use invalid_rule_keys() instead.
@@ -312,4 +332,18 @@ invalid_keys() is deprecated. Use invalid_rule_keys() instead.
 
 Invalid rule keys.
 
+=head2 C<(deprecated) is_valid>
+
+is_valid() is deprecated. Use is_ok() instead.
+
+    $is_valid = $result->is_valid;
+
+Check if the result is valid.
+
+=head2 C<(depricated) remove_error_info>
+
+    $result->remove_error_info($name);
+
+Remove error information.
+
 =cut
